==> qt-x11-opensource-src-4.3.5.tar.gz: qt-x11-opensource-src-4.3.5/tools/designer/src/lib/shared/qdesigner_propertycommentcommand_p.h <==
/****************************************************************************
**
** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
**
** This file is part of the Qt Designer of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License versions 2.0 or 3.0 as published by the Free Software
** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file.  Alternatively you may (at
** your option) use any later version of the GNU General Public
** License if such license has been publicly approved by Trolltech ASA
** (or its successors, if any) and the KDE Free Qt Foundation. In
** addition, as a special exception, Trolltech gives you certain
** additional rights. These rights are described in the Trolltech GPL
** Exception version 1.2, which can be found at
** http://www.trolltech.com/products/qt/gplexception/ and in the file
** GPL_EXCEPTION.txt in this package.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
** you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** In addition, as a special exception, Trolltech, as the sole
** copyright holder for Qt Designer, grants users of the Qt/Eclipse
** Integration plug-in the right for the Qt/Eclipse Integration to
** link to functionality provided by Qt Designer and its related
** libraries.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
** granted herein.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of Qt Designer.  This header
// file may change from version to version without notice, or even be removed.
//
// We mean it.
//

#ifndef QDESIGNER_PROPERTYCOMMENTCOMMAND_H
#define QDESIGNER_PROPERTYCOMMENTCOMMAND_H

#include "qdesigner_formwindowcommand_p.h"

#include <QtCore/QList>
#include <QtCore/QVariant>

class QDesignerFormWindowInterface;

namespace qdesigner_internal {

class QDESIGNER_SHARED_EXPORT SetPropertyCommentCommand: public QDesignerFormWindowCommand
{
    SetPropertyCommentCommand(const SetPropertyCommentCommand &);
    SetPropertyCommentCommand& operator=(const SetPropertyCommentCommand &);

public:
    SetPropertyCommentCommand(QDesignerFormWindowInterface *formWindow);

    bool init(QObject *object, const QString &propertyName, const QString &newCommentValue);

    typedef QList<QObject *> ObjectList;
    bool init(const ObjectList &list, const QString &propertyName, const QString &newCommentValue);

    int id() const;
    bool mergeWith(const QUndoCommand *other);

    virtual void redo();
    virtual void undo();

private:
    bool add(QObject *object);
    void setDescription();

    struct Entry {
        Entry(QObject* object, const QString &oldCommentValue);
        QPointer<QObject> m_object;
        QString m_oldCommentValue;
    };

    typedef QList<Entry> EntryList;
    EntryList m_Entries;

    QVariant::Type m_propertyType;
    QString m_propertyName;
    QString m_newCommentValue;
};


} // namespace qdesigner_internal

#endif // QDESIGNER_PROPERTYCOMMENTCOMMAND_H

==> qt-x11-opensource-src-4.4.1.tar.gz: qt-x11-opensource-src-4.4.1/tools/designer/src/lib/shared/qdesigner_propertycommentcommand_p.h <==
/****************************************************************************
**
** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
**
** This file is part of the Qt Designer of the Qt Toolkit.
**
** This file may be used under the terms of the GNU General Public
** License versions 2.0 or 3.0 as published by the Free Software
** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file.  Alternatively you may (at
** your option) use any later version of the GNU General Public
** License if such license has been publicly approved by Trolltech ASA
** (or its successors, if any) and the KDE Free Qt Foundation. In
** addition, as a special exception, Trolltech gives you certain
** additional rights. These rights are described in the Trolltech GPL
** Exception version 1.2, which can be found at
** http://www.trolltech.com/products/qt/gplexception/ and in the file
** GPL_EXCEPTION.txt in this package.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
** you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** In addition, as a special exception, Trolltech, as the sole
** copyright holder for Qt Designer, grants users of the Qt/Eclipse
** Integration plug-in the right for the Qt/Eclipse Integration to
** link to functionality provided by Qt Designer and its related
** libraries.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
** granted herein.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
****************************************************************************/

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of Qt Designer.  This header
// file may change from version to version without notice, or even be removed.
//
// We mean it.
//

#ifndef QDESIGNER_PROPERTYCOMMENTCOMMAND_H
#define QDESIGNER_PROPERTYCOMMENTCOMMAND_H

#include "qdesigner_formwindowcommand_p.h"

#include <QtCore/QList>
#include <QtCore/QVariant>

QT_BEGIN_NAMESPACE

class QDesignerFormWindowInterface;

namespace qdesigner_internal {

class QDESIGNER_SHARED_EXPORT SetPropertyCommentCommand: public QDesignerFormWindowCommand
{
    SetPropertyCommentCommand(const SetPropertyCommentCommand &);
    SetPropertyCommentCommand& operator=(const SetPropertyCommentCommand &);

public:
    explicit SetPropertyCommentCommand(QDesignerFormWindowInterface *formWindow);

    bool init(QObject *object, const QString &propertyName, const QString &newCommentValue);

    typedef QList<QObject *> ObjectList;
    bool init(const ObjectList &list, const QString &propertyName, const QString &newCommentValue);

    int id() const;
    bool mergeWith(const QUndoCommand *other);

    virtual void redo();
    virtual void undo();

private:
    bool add(QObject *object);
    void setDescription();

    struct Entry {
        Entry(QObject* object, const QString &oldCommentValue);
        QPointer<QObject> m_object;
        QString m_oldCommentValue;
    };

    typedef QList<Entry> EntryList;
    EntryList m_Entries;

    QVariant::Type m_propertyType;
    QString m_propertyName;
    QString m_newCommentValue;
};

} // namespace qdesigner_internal

QT_END_NAMESPACE

#endif // QDESIGNER_PROPERTYCOMMENTCOMMAND_H
